@@ -95,6 +95,8 @@ var targets = []target{
 	{"darwin", "amd64", ""},
 	{"darwin", "arm64", ""},
 	{"windows", "amd64", ""},
+	{"windows", "arm64", ""},
 	{"windows", "386", ""},
 	{"freebsd", "amd64", ""},
+	{"netbsd", "amd64", ""},
 }
